/*
  Knotify Plugin for Pidgin
  
  Description:  This plugin allows Pidgin to use knotify to make 
                notifications when buddies sign on, log off and change status.
  Author: Kyle Cunningham <kyle@codeincarnate.com>
  Version: 0.1
  
  
  This plugin is licensed under the LGPLv2 the text of which can be found at http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
*/


#define PURPLE_PLUGINS

#include <glib.h>
#include <glib/gprintf.h>
#include <stdlib.h>


#include "connection.h"
#include "conversation.h"
#include "core.h"
#include "signals.h"
#include "version.h"
#include "status.h"

#define PLUGIN_AUTHOR "Kyle Cunningham <kyle@codeincarnate.com>"
#define PLUGIN_VERSION "0.1"

gchar dcopmessage[400];

static void
buddy_signed_on_cb(PurpleBuddy *buddy, void *data)
{
  if(buddy->alias == NULL)
  {
    g_sprintf(dcopmessage,"dcop knotify default notify eventname 'Buddy Connected' '%s has signed on.' '' '' 16 0",buddy->name);
  }
  else
  {
    g_sprintf(dcopmessage,"dcop knotify default notify eventname 'Buddy Connected' '%s has signed on.' '' '' 16 0",buddy->alias);
  }
    
  system(dcopmessage);
}

static void
buddy_signed_off_cb(PurpleBuddy *buddy, void *data)
{
  if(buddy->alias == NULL)
  {
    g_sprintf(dcopmessage,"dcop knotify default notify eventname 'Buddy Disconnected' '%s has signed off.' '' '' 16 0",buddy->name);
  }
  else
  {
    g_sprintf(dcopmessage,"dcop knotify default notify eventname 'Buddy Disconnected' '%s has signed off.' '' '' 16 0",buddy->alias);
  }
  
  system(dcopmessage);
}

static void
buddy_status_changed_cb(PurpleBuddy *buddy, PurpleStatus *old_status, PurpleStatus *status, void *data)
{
  g_sprintf(dcopmessage,"dcop knotify default notify eventname 'Buddy Changed Status' '%s has gone %s.' '' '' 16 0",buddy->alias,purple_status_get_name(status) );
  system(dcopmessage);
}

static gboolean
plugin_load(PurplePlugin *plugin){
  void *blist_handle = purple_blist_get_handle(); 
 
  /* Connect signals here */
  purple_signal_connect( blist_handle, "buddy-signed-on", plugin, PURPLE_CALLBACK(buddy_signed_on_cb), NULL);
  purple_signal_connect( blist_handle, "buddy-signed-off", plugin, PURPLE_CALLBACK(buddy_signed_off_cb), NULL);
  purple_signal_connect( blist_handle, "buddy-status-changed", plugin, PURPLE_CALLBACK(buddy_status_changed_cb), NULL);
  
  
  return TRUE;
}


static PurplePluginInfo info = 
{
  PURPLE_PLUGIN_MAGIC,
  PURPLE_MAJOR_VERSION,
  PURPLE_MINOR_VERSION,
  PURPLE_PLUGIN_STANDARD,
  NULL,
  0,
  NULL,
  PURPLE_PRIORITY_DEFAULT,

  "pidgin-knotify",
  "Knotify for Pidgin",
  PLUGIN_VERSION,

  "Pidgin Knotify Plugin",
  "A simple plugin for displaying Knotify dialogs for Pidgin events.",
  PLUGIN_AUTHOR,
  "http://www.codeincarnate.com",

  plugin_load,
  NULL,
  NULL,

  NULL,
  NULL,
  NULL,
  NULL
};

static void
init_plugin(PurplePlugin *plugin){
}

PURPLE_INIT_PLUGIN(knotify_plugin,init_plugin,info);
